Absolute imports were strongly preferred, historically. Relative imports allow you
to reorganize packages without changing any code, but these days refactoring tools and IDEs
allow you to do that at almost no cost anyway if the imports are explicit/absolute.
Therefore, absolute imports are often still preferred over relative ones.
